<?php

namespace Bixo\Deal\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Deal\Models\Deal;

class DealPolicy
{

    /**
     * Determine if the given user can view the deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function view(UserPolicy $user, Deal $deal)
    {
        if ($user->canDo('deal.deal.view') && $user->isAdmin()) {
            return true;
        }

        return $deal->user_id == user_id() && $deal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('deal.deal.create');
    }

    /**
     * Determine if the given user can update the given deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function update(UserPolicy $user, Deal $deal)
    {
        if ($user->canDo('deal.deal.edit') && $user->isAdmin()) {
            return true;
        }

        return $deal->user_id == user_id() && $deal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Deal $deal)
    {
        return $deal->user_id == user_id() && $deal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Deal $deal)
    {
        if ($user->canDo('deal.deal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given deal.
     *
     * @param UserPolicy $user
     * @param Deal $deal
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Deal $deal)
    {
        if ($user->canDo('deal.deal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
